@@ -3,6 +3,7 @@ import functools
 import os
 import re
 import sys
+import textwrap
 from types import ModuleType
 from typing import (
     Any,
@@ -50,11 +51,21 @@ class VerticalHelpFormatter(argparse.HelpFormatter):
         for line in result.splitlines(keepends=True):
             # All of our resources are on one line and wrapped inside braces.
             # For example: {application,resource1,resource2}
+            # except if there are fewer resources - then the line and help text
+            # are collapsed on the same line.
+            # For example:  {list}      Action to execute on the GitLab resource.
             # We then put each resource on its own line to make it easier to read.
             if line.strip().startswith("{"):
-                choices = line.strip().strip("{}").split(",")
-                choices_str = f"\n{indent}".join(choices)
-                line = f"{indent}{choices_str}\n"
+                choice_string, help_string = line.split("}", 1)
+                choice_list = choice_string.strip(" {").split(",")
+                help_string = help_string.strip()
+
+                if help_string:
+                    help_indent = len(max(choice_list, key=len)) * " "
+                    choice_list.append(f"{help_indent} {help_string}")
+
+                choices = "\n".join(choice_list)
+                line = f"{textwrap.indent(choices, indent)}\n"
             output += line
         return output
 
@@ -183,14 +194,25 @@ def _get_base_parser(add_help: bool = True) -> argparse.ArgumentParser:
         required=False,
         default=os.getenv("GITLAB_URL"),
     )
-    parser.add_argument(
+
+    ssl_verify_group = parser.add_mutually_exclusive_group()
+    ssl_verify_group.add_argument(
         "--ssl-verify",
         help=(
-            "Whether SSL certificates should be validated. [env var: GITLAB_SSL_VERIFY]"
+            "Path to a CA_BUNDLE file or directory with certificates of trusted CAs. "
+            "[env var: GITLAB_SSL_VERIFY]"
         ),
         required=False,
         default=os.getenv("GITLAB_SSL_VERIFY"),
     )
+    ssl_verify_group.add_argument(
+        "--no-ssl-verify",
+        help="Disable SSL verification",
+        required=False,
+        dest="ssl_verify",
+        action="store_false",
+    )
+
     parser.add_argument(
         "--timeout",
         help=(
@@ -272,6 +294,8 @@ def _get_parser() -> argparse.ArgumentParser:
 
 
 def _parse_value(v: Any) -> Any:
+    if isinstance(v, str) and v.startswith("@@"):
+        return v[1:]
     if isinstance(v, str) and v.startswith("@"):
         # If the user-provided value starts with @, we try to read the file
         # path provided after @ as the real value. Exit on any error.
@@ -313,7 +337,7 @@ def main() -> None:
         if "--help" in sys.argv or "-h" in sys.argv:
             parser.print_help()
             sys.exit(0)
-        sys.exit(e)
+        sys.exit(str(e))
     # We only support v4 API at this time
     if config.api_version not in ("4",):  # dead code # pragma: no cover
         raise ModuleNotFoundError(f"gitlab.v{config.api_version}.cli")
