@@ -1,3 +1,4 @@
+import enum
 from types import ModuleType
 from typing import (
     Any,
@@ -304,6 +305,13 @@ class CreateMixin(_RestManagerBase):
         return self._obj_cls(self, server_data)
 
 
+@enum.unique
+class UpdateMethod(enum.IntEnum):
+    PUT = 1
+    POST = 2
+    PATCH = 3
+
+
 class UpdateMixin(_RestManagerBase):
     _computed_path: Optional[str]
     _from_parent_attrs: Dict[str, Any]
@@ -311,7 +319,7 @@ class UpdateMixin(_RestManagerBase):
     _parent: Optional[base.RESTObject]
     _parent_attrs: Dict[str, Any]
     _path: Optional[str]
-    _update_uses_post: bool = False
+    _update_method: UpdateMethod = UpdateMethod.PUT
     gitlab: gitlab.Gitlab
 
     def _get_update_method(
@@ -322,8 +330,11 @@ class UpdateMixin(_RestManagerBase):
         Returns:
             http_put (default) or http_post
         """
-        if self._update_uses_post:
+        if self._update_method is UpdateMethod.POST:
             http_method = self.gitlab.http_post
+        elif self._update_method is UpdateMethod.PATCH:
+            # only patch uses required kwargs, so our types are a bit misaligned
+            http_method = self.gitlab.http_patch  # type: ignore[assignment]
         else:
             http_method = self.gitlab.http_put
         return http_method
@@ -894,7 +905,7 @@ class PromoteMixin(_RestObjectBase):
     _module: ModuleType
     _parent_attrs: Dict[str, Any]
     _updated_attrs: Dict[str, Any]
-    _update_uses_post: bool = False
+    _update_method: UpdateMethod = UpdateMethod.PUT
     manager: base.RESTManager
 
     def _get_update_method(
@@ -905,7 +916,7 @@ class PromoteMixin(_RestObjectBase):
         Returns:
             http_put (default) or http_post
         """
-        if self._update_uses_post:
+        if self._update_method is UpdateMethod.POST:
             http_method = self.manager.gitlab.http_post
         else:
             http_method = self.manager.gitlab.http_put
@@ -933,3 +944,73 @@ class PromoteMixin(_RestObjectBase):
         if TYPE_CHECKING:
             assert not isinstance(result, requests.Response)
         return result
+
+
+class UploadMixin(_RestObjectBase):
+    _id_attr: Optional[str]
+    _attrs: Dict[str, Any]
+    _module: ModuleType
+    _parent_attrs: Dict[str, Any]
+    _updated_attrs: Dict[str, Any]
+    _upload_path: str
+    manager: base.RESTManager
+
+    def _get_upload_path(self) -> str:
+        """Formats _upload_path with object attributes.
+
+        Returns:
+            The upload path
+        """
+        if TYPE_CHECKING:
+            assert isinstance(self._upload_path, str)
+        data = self.attributes
+        return self._upload_path.format(**data)
+
+    @cli.register_custom_action(("Project", "ProjectWiki"), ("filename", "filepath"))
+    @exc.on_http_error(exc.GitlabUploadError)
+    def upload(
+        self,
+        filename: str,
+        filedata: Optional[bytes] = None,
+        filepath: Optional[str] = None,
+        **kwargs: Any,
+    ) -> Dict[str, Any]:
+        """Upload the specified file.
+
+        .. note::
+
+            Either ``filedata`` or ``filepath`` *MUST* be specified.
+
+        Args:
+            filename: The name of the file being uploaded
+            filedata: The raw data of the file being uploaded
+            filepath: The path to a local file to upload (optional)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabUploadError: If the file upload fails
+            GitlabUploadError: If ``filedata`` and ``filepath`` are not
+                specified
+            GitlabUploadError: If both ``filedata`` and ``filepath`` are
+                specified
+
+        Returns:
+            A ``dict`` with info on the uploaded file
+        """
+        if filepath is None and filedata is None:
+            raise exc.GitlabUploadError("No file contents or path specified")
+
+        if filedata is not None and filepath is not None:
+            raise exc.GitlabUploadError("File contents and file path specified")
+
+        if filepath is not None:
+            with open(filepath, "rb") as f:
+                filedata = f.read()
+
+        file_info = {"file": (filename, filedata)}
+        path = self._get_upload_path()
+        server_data = self.manager.gitlab.http_post(path, files=file_info, **kwargs)
+
+        if TYPE_CHECKING:
+            assert isinstance(server_data, dict)
+        return server_data
