@@ -5,8 +5,9 @@ import requests
 import gitlab
 from gitlab import cli
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import CreateMixin, ListMixin, RefreshMixin, RetrieveMixin
+from gitlab.types import RequiredOptional
 
 from .discussions import ProjectCommitDiscussionManager  # noqa: F401
 
@@ -154,6 +155,7 @@ class ProjectCommitManager(RetrieveMixin, CreateMixin, RESTManager):
         optional=("author_email", "author_name"),
     )
     _list_filters = (
+        "all",
         "ref_name",
         "since",
         "until",
