@@ -4,7 +4,7 @@ import requests
 
 from gitlab import cli
 from gitlab import exceptions as exc
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import (
     CreateMixin,
     DeleteMixin,
@@ -13,10 +13,13 @@ from gitlab.mixins import (
     SaveMixin,
     UpdateMixin,
 )
+from gitlab.types import ArrayAttribute, RequiredOptional
 
 __all__ = [
     "ProjectEnvironment",
     "ProjectEnvironmentManager",
+    "ProjectProtectedEnvironment",
+    "ProjectProtectedEnvironmentManager",
 ]
 
 
@@ -54,3 +57,31 @@ class ProjectEnvironmentManager(
         self, id: Union[str, int], lazy: bool = False, **kwargs: Any
     ) -> ProjectEnvironment:
         return cast(ProjectEnvironment, super().get(id=id, lazy=lazy, **kwargs))
+
+
+class ProjectProtectedEnvironment(ObjectDeleteMixin, RESTObject):
+    _id_attr = "name"
+    _repr_attr = "name"
+
+
+class ProjectProtectedEnvironmentManager(
+    RetrieveMixin, CreateMixin, DeleteMixin, RESTManager
+):
+    _path = "/projects/{project_id}/protected_environments"
+    _obj_cls = ProjectProtectedEnvironment
+    _from_parent_attrs = {"project_id": "id"}
+    _create_attrs = RequiredOptional(
+        required=(
+            "name",
+            "deploy_access_levels",
+        ),
+        optional=("required_approval_count", "approval_rules"),
+    )
+    _types = {"deploy_access_levels": ArrayAttribute, "approval_rules": ArrayAttribute}
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectProtectedEnvironment:
+        return cast(
+            ProjectProtectedEnvironment, super().get(id=id, lazy=lazy, **kwargs)
+        )
