@@ -1,5 +1,8 @@
-from gitlab.base import RequiredOptional, RESTManager, RESTObject
+from typing import Any, cast, Union
+
+from gitlab.base import RESTManager, RESTObject
 from gitlab.mixins import CRUDMixin, ListMixin, ObjectDeleteMixin, SaveMixin
+from gitlab.types import RequiredOptional
 
 __all__ = [
     "PagesDomain",
@@ -23,10 +26,15 @@ class ProjectPagesDomain(SaveMixin, ObjectDeleteMixin, RESTObject):
 
 
 class ProjectPagesDomainManager(CRUDMixin, RESTManager):
-    _path = "/projects/%(project_id)s/pages/domains"
+    _path = "/projects/{project_id}/pages/domains"
     _obj_cls = ProjectPagesDomain
     _from_parent_attrs = {"project_id": "id"}
     _create_attrs = RequiredOptional(
         required=("domain",), optional=("certificate", "key")
     )
     _update_attrs = RequiredOptional(optional=("certificate", "key"))
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectPagesDomain:
+        return cast(ProjectPagesDomain, super().get(id=id, lazy=lazy, **kwargs))
