@@ -12,3 +12,10 @@ def test_create_user_impersonation_token_with_scopes(gitlab_cli, user):
     ret = gitlab_cli(cmd)
 
     assert ret.success
+
+
+def test_list_user_projects(gitlab_cli, user):
+    cmd = ["user-project", "list", "--user-id", user.id]
+    ret = gitlab_cli(cmd)
+
+    assert ret.success
