@@ -23,7 +23,7 @@ billable_members_content = [
 
 
 @pytest.fixture
-def resp_create_group_member(no_content):
+def resp_create_group_member():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.POST,
@@ -49,13 +49,11 @@ def resp_list_billable_group_members():
 
 
 @pytest.fixture
-def resp_delete_billable_group_member(no_content):
+def resp_delete_billable_group_member():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/groups/1/billable_members/1",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
