@@ -6,11 +6,13 @@ import re
 import pytest
 import responses
 
+from gitlab import exceptions as exc
 from gitlab.v4.objects import (
     GenericPackage,
     GroupPackage,
     ProjectPackage,
     ProjectPackageFile,
+    ProjectPackagePipeline,
 )
 
 package_content = {
@@ -103,6 +105,50 @@ package_file_content = [
     },
 ]
 
+package_pipeline_content = [
+    {
+        "id": 123,
+        "iid": 1,
+        "project_id": 1,
+        "sha": "a91957a858320c0e17f3a0eca7cfacbff50ea29a",
+        "ref": "new-pipeline",
+        "status": "failed",
+        "source": "push",
+        "created_at": "2016-08-11T11:28:34.085Z",
+        "updated_at": "2016-08-11T11:32:35.169Z",
+        "web_url": "https://example.com/foo/bar/pipelines/47",
+        "user": {
+            "id": 1,
+            "username": "root",
+            "name": "Administrator",
+            "state": "active",
+            "avatar_url": "https://www.gravatar.com/avatar/e64c7d89f26bd1972efa854d13d7dd61?s=80\u0026d=identicon",
+            "web_url": "http://gdk.test:3001/root",
+        },
+    },
+    {
+        "id": 234,
+        "iid": 2,
+        "project_id": 1,
+        "sha": "a91957a858320c0e17f3a0eca7cfacbff50ea29a",
+        "ref": "new-pipeline",
+        "status": "failed",
+        "source": "push",
+        "created_at": "2016-08-11T11:28:34.085Z",
+        "updated_at": "2016-08-11T11:32:35.169Z",
+        "web_url": "https://example.com/foo/bar/pipelines/58",
+        "user": {
+            "id": 1,
+            "username": "root",
+            "name": "Administrator",
+            "state": "active",
+            "avatar_url": "https://www.gravatar.com/avatar/e64c7d89f26bd1972efa854d13d7dd61?s=80\u0026d=identicon",
+            "web_url": "http://gdk.test:3001/root",
+        },
+    },
+]
+
+
 package_name = "hello-world"
 package_version = "v1.0.0"
 file_name = "hello.tar.gz"
@@ -137,33 +183,29 @@ def resp_get_package():
 
 
 @pytest.fixture
-def resp_delete_package(no_content):
+def resp_delete_package():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/projects/1/packages/1",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
 
 
 @pytest.fixture
-def resp_delete_package_file(no_content):
+def resp_delete_package_file():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.DELETE,
             url="http://localhost/api/v4/projects/1/packages/1/package_files/1",
-            json=no_content,
-            content_type="application/json",
             status=204,
         )
         yield rsps
 
 
 @pytest.fixture
-def resp_delete_package_file_list(no_content):
+def resp_delete_package_file_list():
     with responses.RequestsMock() as rsps:
         rsps.add(
             method=responses.GET,
@@ -178,8 +220,6 @@ def resp_delete_package_file_list(no_content):
             rsps.add(
                 method=responses.DELETE,
                 url=f"http://localhost/api/v4/projects/1/packages/1/package_files/{pkg_file_id}",
-                json=no_content,
-                content_type="application/json",
                 status=204,
             )
         yield rsps
@@ -200,6 +240,19 @@ def resp_list_package_files():
         yield rsps
 
 
+@pytest.fixture
+def resp_list_package_pipelines():
+    with responses.RequestsMock() as rsps:
+        rsps.add(
+            method=responses.GET,
+            url=re.compile(r"http://localhost/api/v4/projects/1/packages/1/pipelines"),
+            json=package_pipeline_content,
+            content_type="application/json",
+            status=200,
+        )
+        yield rsps
+
+
 @pytest.fixture
 def resp_upload_generic_package(created_content):
     with responses.RequestsMock() as rsps:
@@ -274,6 +327,14 @@ def test_delete_project_package_file_from_package_file_object(
         package_file.delete()
 
 
+def test_list_project_package_pipelines(project, resp_list_package_pipelines):
+    package = project.packages.get(1, lazy=True)
+    pipelines = package.pipelines.list()
+    assert isinstance(pipelines, list)
+    assert isinstance(pipelines[0], ProjectPackagePipeline)
+    assert pipelines[0].id == 123
+
+
 def test_upload_generic_package(tmp_path, project, resp_upload_generic_package):
     path = tmp_path / file_name
     path.write_text(file_content, encoding="utf-8")
@@ -287,6 +348,74 @@ def test_upload_generic_package(tmp_path, project, resp_upload_generic_package):
     assert isinstance(package, GenericPackage)
 
 
+def test_upload_generic_package_nonexistent_path(tmp_path, project):
+    with pytest.raises(exc.GitlabUploadError):
+        project.generic_packages.upload(
+            package_name=package_name,
+            package_version=package_version,
+            file_name=file_name,
+            path="bad",
+        )
+
+
+def test_upload_generic_package_no_file_and_no_data(tmp_path, project):
+    path = tmp_path / file_name
+
+    path.write_text(file_content, encoding="utf-8")
+
+    with pytest.raises(exc.GitlabUploadError):
+        project.generic_packages.upload(
+            package_name=package_name,
+            package_version=package_version,
+            file_name=file_name,
+        )
+
+
+def test_upload_generic_package_file_and_data(tmp_path, project):
+    path = tmp_path / file_name
+
+    path.write_text(file_content, encoding="utf-8")
+
+    with pytest.raises(exc.GitlabUploadError):
+        project.generic_packages.upload(
+            package_name=package_name,
+            package_version=package_version,
+            file_name=file_name,
+            path=path,
+            data=path.read_bytes(),
+        )
+
+
+def test_upload_generic_package_bytes(tmp_path, project, resp_upload_generic_package):
+    path = tmp_path / file_name
+
+    path.write_text(file_content, encoding="utf-8")
+
+    package = project.generic_packages.upload(
+        package_name=package_name,
+        package_version=package_version,
+        file_name=file_name,
+        data=path.read_bytes(),
+    )
+
+    assert isinstance(package, GenericPackage)
+
+
+def test_upload_generic_package_file(tmp_path, project, resp_upload_generic_package):
+    path = tmp_path / file_name
+
+    path.write_text(file_content, encoding="utf-8")
+
+    package = project.generic_packages.upload(
+        package_name=package_name,
+        package_version=package_version,
+        file_name=file_name,
+        data=path.open(mode="rb"),
+    )
+
+    assert isinstance(package, GenericPackage)
+
+
 def test_download_generic_package(project, resp_download_generic_package):
     package = project.generic_packages.download(
         package_name=package_name,
